@@ -143,7 +143,8 @@ int  subcmeans(int *xrows, int *xcols, double *x, int *ncenters,
   /* *ermin=*ermin/(*xrows));*/
 
   if (conv<= ((*xrows)*(*xcols)*epsi1)){
-      Rprintf("Iteration: %3d    converged, Error:   %13.10f\n",*iter,*ermin/(*xrows));
+      if (*verbose){
+      Rprintf("Iteration: %3d    converged, Error:   %13.10f\n",*iter,*ermin/(*xrows));}
       /**iter=*itermax;}*/
       *converge=0;}
   else
@@ -362,7 +363,8 @@ int  subufcl(int *xrows, int *xcols, double *x, int *ncenters,
   /* *ermin=*ermin/(*xrows));*/
 
   if (conv<= ((*xrows)*(*xcols)*epsi1)){
-      Rprintf("Iteration: %3d    converged, Error:   %13.10f\n",*iter,*ermin/(*xrows));
+      if (*verbose){
+      Rprintf("Iteration: %3d    converged, Error:   %13.10f\n",*iter,*ermin/(*xrows));}
       /**iter=*itermax;}*/
       *converge=0;}
   else
